FlutterDesktopSleepPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterDesktopSleepPlatform
Implementers

Constructors

FlutterDesktopSleepPlatform()
Constructs a FlutterDesktopSleepPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setWindowSleepHandler(Future<void> handler(String?)?) → void
terminateApp() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterDesktopSleepPlatform
The default instance of FlutterDesktopSleepPlatform to use.
getter/setter pair